@@ -3,32 +3,30 @@ import sys
 import logging
 import ctypes.util
 
-from .. import base, GPUDevice, flags, enums
-
-
 logger = logging.getLogger("wgpu")
 
 
-class WgpuCanvasInterface(base.GPUCanvasContext):
+class WgpuCanvasInterface:
     """This is the interface that a canvas object must implement in order
     to be a valid canvas that wgpu can work with.
     """
 
-    # NOTE: It is not necessary to actually subclass this class.
+    # NOTE: This is an interface - it should not be necessary to actually subclass
 
     def __init__(self, *args, **kwargs):
         # The args/kwargs are there because we may be mixed with e.g. a Qt widget
         super().__init__(*args, **kwargs)
+        self._canvas_context = None
 
     def get_window_id(self):
-        """Get the native window id. This is used by the backends
-        to obtain a surface id.
+        """Get the native window id. This is used to obtain a surface id,
+        so that wgpu can render to the region of the screen occupied by the canvas.
         """
         raise NotImplementedError()
 
     def get_display_id(self):
-        """Get the native display id on Linux. This is used by the backends
-        to obtain a surface id on Linux. The default implementation calls into
+        """Get the native display id on Linux. This is needed in addition to the
+        window id to obtain a surface id. The default implementation calls into
         the X11 lib to get the display id.
         """
         # Re-use to avoid creating loads of id's
@@ -51,35 +49,31 @@ class WgpuCanvasInterface(base.GPUCanvasContext):
         return self._display_id
 
     def get_physical_size(self):
-        """Get the physical size in integer pixels."""
+        """Get the physical size of the canvas in integer pixels."""
         raise NotImplementedError()
 
-    def configure_swap_chain(
-        self,
-        *,
-        label="",
-        device: "GPUDevice",
-        format: "enums.TextureFormat" = None,
-        usage: "flags.TextureUsage" = None,
-    ):
-        """Obtain a swap-chain object."""
-        # Let's be nice and allow not-specifying the format
-        format = format or self.get_swap_chain_preferred_format(device.adapter)
-        return super().configure_swap_chain(
-            label=label, device=device, format=format, usage=usage
-        )
-
-    def get_swap_chain_preferred_format(self, adapter):
-        """Get the preferred swap-chain texture format for this canvas."""
-        return "bgra8unorm-srgb"  # seems to be a good default, can be overridden
+    def get_context(self, kind="gpupresent"):
+        """Get the GPUCanvasContext object corresponding to this canvas,
+        which can be used to e.g. obtain a texture to render to.
+        """
+        # Note that this function is analog to HtmlCanvas.get_context(), except
+        # here the only valid arg is 'gpupresent', which is also made the default.
+        assert kind == "gpupresent"
+        if self._canvas_context is None:
+            # Get the active wgpu backend module
+            backend_module = sys.modules["wgpu"].GPU.__module__
+            # Instantiate the context
+            PC = sys.modules[backend_module].GPUCanvasContext  # noqa: N806
+            self._canvas_context = PC(self)
+        return self._canvas_context
 
 
 class WgpuCanvasBase(WgpuCanvasInterface):
-    """An abstract class, extending :class:`WgpuCanvasInterface`,
+    """An abstract class extending :class:`WgpuCanvasInterface`,
     that provides a base canvas for various GUI toolkits, so
     that basic canvas functionality is available via a common API.
 
-    It convenient, but not required to use this class (or any of its
+    It is convenient - but not required - to use this class (or any of its
     subclasses) to use wgpu-py.
     """
 
@@ -103,15 +97,21 @@ class WgpuCanvasBase(WgpuCanvasInterface):
         self._request_draw()
 
     def _draw_frame_and_present(self):
-        """Draw the frame and present the swapchain. Errors are logged to the
+        """Draw the frame and present the result. Errors are logged to the
         "wgpu" logger. Should be called by the subclass at an appropriate time.
         """
         # Perform the user-defined drawing code. When this errors,
         # we should report the error and then continue, otherwise we crash.
+        # Returns the result of the context's present() call or None.
         try:
             self.draw_frame()
         except Exception as err:
             self._log_exception("Draw error", err)
+        try:
+            if self._canvas_context:
+                return self._canvas_context.present()
+        except Exception as err:
+            self._log_exception("Present error", err)
 
     def _log_exception(self, kind, err):
         """Log the given exception instance, but only log a one-liner for
